Autowire
========

.. image:: https://img.shields.io/pypi/v/Autowire.svg
    :alt: PyPI Package Version
    :target: https://pypi.python.org/pypi/Autowire

.. image:: http://readthedocs.org/projects/autowire/badge/?version=latest
    :alt: Documentation Status
    :target: http://autowire.readthedocs.org/en/latest/?badge=latest

.. image:: https://codecov.io/gh/Hardtack/Autowire/branch/develop/graph/badge.svg?token=Xr943HH5xi
    :alt: Codcov Coverage
    :target: https://codecov.io/gh/Hardtack/Autowire

Autowire is lightweight & simple dependency injection library for Python.

.. _PEP343: https://www.python.org/dev/peps/pep-0343/


Requirements
------------

Python 3.8+


Documentation
=============

http://autowire.readthedocs.io/en/latest/


Run Test
--------

Just use `tox <https://tox.readthedocs.io>`_ for testing.

.. code-block:: bash

    $ tox
